==> qtjambi-qt3drender-6.6.0-sources.jar: io/qt/qt3d/render/QFrustumCulling.java <==
package io.qt.qt3d.render;

import io.qt.*;


/**
 * <p>Enable frustum culling for the FrameGraph</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qt3drender-qfrustumculling.html">Qt3DRender::QFrustumCulling</a></code></p>
 */
public class QFrustumCulling extends io.qt.qt3d.render.QFrameGraphNode
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QFrustumCulling.class);
    
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qfrustumculling.html#QFrustumCulling">Qt3DRender::QFrustumCulling::<wbr>QFrustumCulling(Qt3DCore::QNode*)</a></code></p>
     */
    @SuppressWarnings({"exports"})
    public QFrustumCulling(io.qt.qt3d.core.@Nullable QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QFrustumCulling instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QFrustumCulling(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * @hidden
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @NativeAccess
    protected QFrustumCulling(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QFrustumCulling instance, QDeclarativeConstructor constructor);
    
    
    /**
     * <p>Overloaded constructor for {@link #QFrustumCulling(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QFrustumCulling() {
        this((io.qt.qt3d.core.QNode)null);
    }
}

==> qtjambi-qt3drender-6.7.1-sources.jar: io/qt/qt3d/render/QFrustumCulling.java <==
package io.qt.qt3d.render;

import io.qt.*;


/**
 * <p>Enable frustum culling for the FrameGraph</p>
 * <p>Java wrapper for Qt class <code><a href="https://doc.qt.io/qt/qt3drender-qfrustumculling.html">Qt3DRender::QFrustumCulling</a></code></p>
 */
public class QFrustumCulling extends io.qt.qt3d.render.QFrameGraphNode
{
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.@NonNull QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QFrustumCulling.class);
    
    
    /**
     * <p>See <code><a href="https://doc.qt.io/qt/qt3drender-qfrustumculling.html#QFrustumCulling">Qt3DRender::QFrustumCulling::<wbr/>QFrustumCulling(Qt3DCore::QNode*)</a></code></p>
     */
    @SuppressWarnings({"exports"})
    public QFrustumCulling(io.qt.qt3d.core.@Nullable QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QFrustumCulling instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     * @hidden
     */
    @NativeAccess
    protected QFrustumCulling(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     * @hidden
     */
    @NativeAccess
    protected QFrustumCulling(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @QtUninvokable
    private static native void initialize_native(QFrustumCulling instance, QDeclarativeConstructor constructor);
    
    
    /**
     * <p>Overloaded constructor for {@link #QFrustumCulling(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QFrustumCulling() {
        this((io.qt.qt3d.core.QNode)null);
    }
}
